{% extends fobi_theme.form_edit_ajax %}

{% load i18n %}

{% block form_page_title %}
{% blocktrans with form_handler_plugin.name as plugin_name %}Add "{{ plugin_name }}" handler to the form{% endblocktrans %}
{% endblock form_page_title %}

{% block form_primary_button_text %}{% trans "Add" %}{% endblock %}
