__title__ = 'fobi.contrib.plugins.form_elements.fields.checkbox_select_multiple'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('default_app_config', 'UID',)

default_app_config = 'fobi.contrib.plugins.form_elements.fields.checkbox_select_multiple.apps.Config'

UID = 'checkbox_select_multiple'
