{% extends "admin/change_form.html" %}
{% load i18n future %}

{% block object-tools %}
{% if change %}
{% if not is_popup %}
    <ul class="object-tools">
    <li><a href="{% url "admin:form_entries" object_id %}">{% trans "View entries" %}</a></li>
    <li><a href="history/" class="historylink">{% trans "History" %}</a></li>
    {% if has_absolute_url %}<li><a href="../../../r/{{ content_type_id }}/{{ object_id }}/" class="viewsitelink">{% trans "View on site" %}</a></li>{% endif%}
    </ul>
{% endif %}
{% endif %}
{% endblock %}

